==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24BorderListener.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$BorderListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 897a6261c68abb83 javax_swing_event_MouseInputAdapter
// @dep_class 20eb20f0647e3553 javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener

// header file dependencies
// @dep_header javax_swing_event_MouseInputAdapter

#include "javax/swing/event/MouseInputAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseClicked$ce03b49f8488a52e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseExited$75603394b87c8a41(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern jint _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$sectionOfClick$c64c481475c6cf78(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, jint, jint);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseClicked$ce03b49f8488a52e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseExited$75603394b87c8a41;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$sectionOfClick$c64c481475c6cf78;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods {
	void	(*mouseClicked$ce03b49f8488a52e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseExited$75603394b87c8a41)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *);
	jint	(*sectionOfClick$c64c481475c6cf78)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, jint, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_MouseInputAdapter$vmethods	javax_swing_event_MouseInputAdapter;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs {
	struct _jc_java_awt_Rectangle$object	*cacheRect;
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
    _jc_javax_swing_event_MouseInputAdapter$sub_refs	javax_swing_event_MouseInputAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs {
	jint	RESIZE__5fNONE;
	jint	xOffset;
	jint	yOffset;
	jint	direction;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_MouseInputAdapter$sub_nonrefs	javax_swing_event_MouseInputAdapter;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24BorderListener.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$BorderListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 897a6261c68abb83 javax_swing_event_MouseInputAdapter
// @dep_class 20eb20f0647e3553 javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener

// header file dependencies
// @dep_header javax_swing_event_MouseInputAdapter

#include "javax/swing/event/MouseInputAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseClicked$ce03b49f8488a52e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseExited$75603394b87c8a41(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$sectionOfClick$c64c481475c6cf78(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseClicked$ce03b49f8488a52e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseExited$75603394b87c8a41;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$sectionOfClick$c64c481475c6cf78;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods {
	void	(*mouseClicked$ce03b49f8488a52e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseExited$75603394b87c8a41)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jint	(*sectionOfClick$c64c481475c6cf78)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_MouseInputAdapter$vmethods	javax_swing_event_MouseInputAdapter;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs {
	struct _jc_java_awt_Rectangle$object	*cacheRect;
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
    _jc_javax_swing_event_MouseInputAdapter$sub_refs	javax_swing_event_MouseInputAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs {
	jint	RESIZE__5fNONE;
	jint	xOffset;
	jint	yOffset;
	jint	direction;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_MouseInputAdapter$sub_nonrefs	javax_swing_event_MouseInputAdapter;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24BorderListener_H_ */
